@@ -8,7 +8,11 @@ simpleClient.py from any computer on your network!
 
 """
 
+import VisionEgg
+VisionEgg.start_default_logging(); VisionEgg.watch_exceptions()
+
 from VisionEgg.Core import *
+from VisionEgg.FlowControl import Presentation
 from VisionEgg.Gratings import *
 from VisionEgg.PyroHelpers import *
 
