@@ -1,12 +1,16 @@
 #!/usr/bin/env python
-"""Sinusoidal grating calculated in realtime."""
+"""Random dot stimulus"""
 
 ############################
 #  Import various modules  #
 ############################
 
-from VisionEgg.Core import *
-from VisionEgg.Dots import *
+import VisionEgg
+VisionEgg.start_default_logging(); VisionEgg.watch_exceptions()
+
+from VisionEgg.Core import get_default_screen, Viewport
+from VisionEgg.FlowControl import Presentation
+from VisionEgg.Dots import DotArea2D
 
 #####################################
 #  Initialize OpenGL window/screen  #
@@ -16,10 +20,11 @@ screen = get_default_screen()
 screen.parameters.bgcolor = (0.0,0.0,0.0,0.0) # make black (RGBA)
 
 ######################################
-#  Create sinusoidal grating object  #
+#  Create random dot stimulus        #
 ######################################
 
-stimulus = DotArea2D( center                  = ( screen.size[0]/2.0, screen.size[1]/2.0 ),
+stimulus = DotArea2D( position                = ( screen.size[0]/2.0, screen.size[1]/2.0 ),
+                      anchor                  = 'center',
                       size                    = ( 300.0 , 300.0 ),
                       signal_fraction         = 0.1,
                       signal_direction_deg    = 180.0,
