@@ -25,7 +25,7 @@ kind of stuff!"""
 # This script can be run on computers without the Vision Egg installed
 import Tkinter, tkMessageBox
 import sys, socket, time, select, re, string, types, traceback
-import Numeric, math
+import numpy, math
 
 # Save a copy of everything sent?
 log_stream = sys.stdout
@@ -111,7 +111,7 @@ class SocketChecker:
     
 class SocketLogger:
     def __init__(self,*args,**kw):
-        self.socket = apply(socket.socket,args,kw)
+        self.socket = socket.socket(*args,**kw)
         for attr in dir(self.socket):
             if attr != "send" and attr != "recv" and attr[:2] != "__":
                 setattr(self,attr,getattr(self.socket,attr))
@@ -126,7 +126,7 @@ class SocketLogger:
 def connect():
     class ConnectWindow(Tkinter.Frame):
         def __init__(self,master=None,host="",port=5000,**kw):
-            apply(Tkinter.Frame.__init__,(self,master),kw)
+            Tkinter.Frame.__init__(self,master,**kw)
             self.next_row = 0
             self.socket = None
             self.buffer = ""
@@ -238,14 +238,14 @@ the server.""").grid(row=self.next_row,column=0,columnspan=2)
 class BarButton(Tkinter.Menubutton):
     # Taken from Guido van Rossum's Tkinter svkill demo
     def __init__(self, master=None, **cnf):
-        apply(Tkinter.Menubutton.__init__, (self, master), cnf)
+        Tkinter.Menubutton.__init__(self, master, **cnf)
         self.pack(side=Tkinter.LEFT)
         self.menu = Tkinter.Menu(self, name='menu')
         self['menu'] = self.menu
 
 class GratingControl(Tkinter.Frame):
     def __init__(self,master=None,socket=None,**kw):
-        apply(Tkinter.Frame.__init__,(self,master),kw)
+        Tkinter.Frame.__init__(self,master,**kw)
         self.socket = socket
         self.next_row = 0
         self.last_values = {}
@@ -602,7 +602,7 @@ class GratingControl(Tkinter.Frame):
 _re_const = re.compile(r'^const\(\s?(.*)\s?\)$',re.DOTALL)
 _re_eval_str = re.compile(r'^eval_str\(\s?(.*)\s?\)$',re.DOTALL)
 _re_exec_str = re.compile(r'^exec_str\(\s?(\*)?\s?(.*)\s?\)$',re.DOTALL)
-_parse_args_globals = {'Numeric':Numeric,'math':math}
+_parse_args_globals = {'numpy':numpy,'math':math}
 _parse_args_locals = {}
 eval_frequency_flags = {
     # eval_frequency flags:
@@ -622,9 +622,9 @@ temporal_variables_flags = {
     'FRAMES_SINCE_GO'   : 0x08,
     }
 
-for key in dir(Numeric):
+for key in dir(numpy):
     if key[:2] != "__":
-        _parse_args_locals[key] = getattr(Numeric,key)
+        _parse_args_locals[key] = getattr(numpy,key)
 for key in dir(math):
     if key[:2] != "__":
         _parse_args_locals[key] = getattr(math,key)
@@ -671,7 +671,7 @@ def parse_tcp_string(tcp_string):
     if not match:
         raise RuntimeError("Unknown value")
     arg_string = match.group(1)
-    args = eval("("+arg_string+",)",_parse_args_globals,_parse_args_locals)
+    args = eval("tuple(("+arg_string+"))",_parse_args_globals,_parse_args_locals)
     num_args = len(args)
     if num_args == 0:
         result = (klass,None,None,None,None,None)
@@ -691,7 +691,7 @@ def parse_tcp_string(tcp_string):
 
 class TCPApp(Tkinter.Frame):
     def __init__(self,master=None,socket=None,starting_buffer=None,**kw):
-        apply(Tkinter.Frame.__init__,(self,master),kw)
+        Tkinter.Frame.__init__(self,master,**kw)
         self.socket = socket
         self.name_dict = {}
         self.other_interested_instances = [] # also want to know what's happening on the socket
